

*** Kevin Ralston 
 
* 28/11/2023 -  NCRM resource

*** Fixed and random effects examples

*** This file contains code to produce fixed and random effect models, 
* including a Mundlak model and the 'Hybrid' variation
* The examples are an adaption and extention from an example 
* in Rabe-Hesketh and Scrondal (2008)

* Rabe-Hesketh, S. and Skrondal, A., 2008. 
* Multilevel and longitudinal modeling using Stata. STATA press.

* a discussion of these models is provided in the document:
* Extended examples of fixed and random effects models for panel data in Stata 
* that is provided as part of this resource

********************************************************************************

* I put stop here to *stop* the programme running entirely if I accidently hit
* cntr R out of habit

stop

***

clear

* open the data data 
use http://www.stata-press.com/data/mlmus2/wagepan

* generate covariates used in Rabe-Hesketh and Scrondal (2008) (RHS)

* the model is slighly complicated, 
*RHS were using it to analyse age, period and cohort effects

* years of education different from high school graduate
gen educt = educ - 12

* years since 1980
gen yeart = year - 1980

keep lwage black yeart nr hisp union married exper educt yeart

summarize

/* Table 3, from working paper, Extended examples of 
fixed and random effects models for panel data in Stata  */

codebook, compact

xtdescribe , i(nr) t(year)

****

/* Models from Table 4, regression models, from working paper 
Extended examples of fixed and random effects models for panel data in Stata  
*/

/**

OLS results show (conservative) standard errors

**/

reg lwage black hisp union married exper yeart educt
est store OLS

/**

OLS result with clustered standard errors
**/

reg lwage black hisp union married exper yeart educt, cluster(nr)
est store clust


* Fixed effect, and Random effects models and a Hausman test

xtreg lwage black hisp union married exper yeart educt, i(nr) fe 
est store fixed

** Random intercepts model

xtreg lwage black hisp union married exper yeart educt, i(nr) re 
est store random

hausman fixed random 

* a Mundlak model

*** You may need to install the mundlak extention programme
*** ssc install mundlak

* a full model output *
mundlak lwage black hisp union married exper yeart educt, full
est store mund

* restricted model output *

mundlak lwage black hisp union married exper yeart educt,

*

* compare the table estimates and their standard errors
estimates table OLS clust fixed random mund, se

/**

/* Model from Table 5, Hybrid Model, from working paper 
Extended examples of fixed and random effects models for panel data in Stata
 */


the hybrid model

Allison, P. D. 2009. Fixed Effects Regression Models. Thousand Oaks, CA:  Sage.

An alternative to the Mundlak approach was proposed by Allison (2009), 
which is sometimes referred to as the ‘hybrid transformation’ or ‘hybrid model’. 
In essence it transforms the original independent variables into group 
mean deviations in addition to including the group means as additional 
explanatory variables. 
The hybrid model can be estimated using the mundlak command 
in Stata with the option hybrid.

**/

* a full hybrid model output using mundlak command

mundlak lwage black hisp union married exper yeart educt, hybrid full

*** There are often a number of ways to obtain models of different types
*** This model can also be obtained with the xthybrid command

*** You may need to install the xthybrid extention programme
* ssc install xthybrid

xthybrid lwage black hisp union married exper yeart educt, clusterid(nr) ///
				family(gaussian) link(identity) 


*******************************************************************************

* note, the models can be saved out to a local file using the Stata 
* programme Asdoc.
* users who do not have this programme will need to install it.

* ssc install asdoc

* 

* this code creates a directory in a c:\drive to place the files
* if you want to put them elsewhere or you are using a Mac or Linux you
* can change this
mkdir c:\FE_RE_models

* OLS results show (conservative) standard errors

asdoc reg lwage black hisp union married exper yeart educt, /// 
			nest save(c:\FE_RE_models\results_RE_FE_v1.doc) replace

* OLS result with clustered standard errors

asdoc reg lwage black hisp union married exper yeart educt, ///
			cluster(nr) nest append save(c:\FE_RE_models\results_RE_FE_v1.doc)

* Fixed effect

asdoc xtreg lwage black hisp union married exper yeart educt, ///
	i(nr) fe text(Fixed Effect) ///
	nest append save(c:\FE_RE_models\results_RE_FE_v1.doc) 

* Random intercepts model

asdoc xtreg lwage black hisp union married exper yeart educt, ///
		i(nr) re text(Random Effect) ///
		nest append save(c:\FE_RE_models\results_RE_FE_v1.doc) 

* restricted model output Mundlak

asdoc mundlak lwage black hisp union married exper yeart educt, ///
		nest append save(c:\FE_RE_models\results_RE_FE_v1.doc)

* hybrid model

asdoc xthybrid lwage black hisp union married exper yeart educt, ///
		clusterid(nr) family(gaussian) link(identity) ///
		replace save(c:\FE_RE_models\results_Hybrid_v1.doc)


